@@ -197,7 +197,7 @@ def parse_construction_info(construction_info_path: Path) -> Order:
             tooth_implant_type = get_text(tooth_node, 'ImplantType')
             implant_system = None
 
-            if part_type == 'Abutment':
+            if is_screw_retained == 'true':
                 implant_system = get_text(tooth_node, 'ImplantLibraryEntryDescriptor')
 
             tooth = Tooth(fdi=tooth_number, color=tooth_color, type=tooth_type,
